package com.huashe.park.core.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.huashe.park.core.mapper.PileMachineInfoMapper;
import com.huashe.park.core.service.IPileMachineInfoService;
import com.huashe.park.domain.entity.PileMachineInfo;

/**
 * 施工桩机信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-12
 */
@Service
public class PileMachineInfoServiceImpl implements IPileMachineInfoService {
    @Autowired
    private PileMachineInfoMapper pileMachineInfoMapper;

    /**
     * 查询施工桩机信息
     * 
     * @param id 施工桩机信息主键
     * @return 施工桩机信息
     */
    @Override
    public PileMachineInfo selectPileMachineInfoById(Long id) {
        return pileMachineInfoMapper.selectPileMachineInfoById(id);
    }

    /**
     * 查询施工桩机信息列表
     * 
     * @param pileMachineInfo 施工桩机信息
     * @return 施工桩机信息
     */
    @Override
    public List<PileMachineInfo> selectPileMachineInfoList(PileMachineInfo pileMachineInfo) {
        return pileMachineInfoMapper.selectPileMachineInfoList(pileMachineInfo);
    }

    /**
     * 新增施工桩机信息
     * 
     * @param pileMachineInfo 施工桩机信息
     * @return 结果
     */
    @Override
    public int insertPileMachineInfo(PileMachineInfo pileMachineInfo) {
        pileMachineInfo.setPwd(pileMachineInfo.getSn() + "381.2371");
        return pileMachineInfoMapper.insertPileMachineInfo(pileMachineInfo);
    }

    /**
     * 修改施工桩机信息
     * 
     * @param pileMachineInfo 施工桩机信息
     * @return 结果
     */
    @Override
    public int updatePileMachineInfo(PileMachineInfo pileMachineInfo) {
        pileMachineInfo.setPwd(pileMachineInfo.getSn() + "381.2371");
        return pileMachineInfoMapper.updatePileMachineInfo(pileMachineInfo);
    }

    /**
     * 批量删除施工桩机信息
     * 
     * @param ids 需要删除的施工桩机信息主键
     * @return 结果
     */
    @Override
    public int deletePileMachineInfoByIds(Long[] ids) {
        return pileMachineInfoMapper.deletePileMachineInfoByIds(ids);
    }

    /**
     * 删除施工桩机信息信息
     * 
     * @param id 施工桩机信息主键
     * @return 结果
     */
    @Override
    public int deletePileMachineInfoById(Long id) {
        return pileMachineInfoMapper.deletePileMachineInfoById(id);
    }
}
